# Generated by Django 5.2.10 on 2026-03-13 17:51

import django.db.models.deletion
import uuid
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_resaas", "0005_corsallowedorigin"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="theme",
            options={
                "permissions": (),
                "verbose_name": "Theme",
                "verbose_name_plural": "Themes",
            },
        ),
        migrations.AddField(
            model_name="layoutsetting",
            name="border_radius",
            field=models.IntegerField(default=8),
        ),
        migrations.AddField(
            model_name="layoutsetting",
            name="buttonDense",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="layoutsetting",
            name="buttonRounded",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="layoutsetting",
            name="buttonSquare",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="layoutsetting",
            name="inputDense",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="layoutsetting",
            name="inputRounded",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="layoutsetting",
            name="inputSquare",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="theme",
            name="background",
            field=models.CharField(default="#F6F8F7", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="background_dark",
            field=models.CharField(default="#121212", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="border",
            field=models.CharField(default="#E0E0E0", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="button_outline",
            field=models.CharField(default="#1976D2", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="button_primary",
            field=models.CharField(default="#1976D2", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="button_primary_text",
            field=models.CharField(default="#FFFFFF", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="button_secondary",
            field=models.CharField(default="#26A69A", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="button_secondary_text",
            field=models.CharField(default="#FFFFFF", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="card",
            field=models.CharField(default="#FFFFFF", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="divider",
            field=models.CharField(default="#EEEEEE", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="footer",
            field=models.CharField(default="#1976D2", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="footer_text",
            field=models.CharField(default="#FFFFFF", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="grey",
            field=models.CharField(default="#CDCDCD", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="grey_1",
            field=models.CharField(default="#FAFAFA", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="grey_2",
            field=models.CharField(default="#F5F5F5", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="grey_3",
            field=models.CharField(default="#EEEEEE", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="grey_4",
            field=models.CharField(default="#E0E0E0", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="grey_5",
            field=models.CharField(default="#BDBDBD", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="grey_6",
            field=models.CharField(default="#9E9E9E", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="grey_7",
            field=models.CharField(default="#757575", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="grey_8",
            field=models.CharField(default="#616161", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="grey_9",
            field=models.CharField(default="#424242", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="header",
            field=models.CharField(default="#1976D2", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="header_text",
            field=models.CharField(default="#FFFFFF", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="input_background",
            field=models.CharField(default="#FFFFFF", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="input_border",
            field=models.CharField(default="#CCCCCC", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="input_focus",
            field=models.CharField(default="#1976D2", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="light",
            field=models.CharField(default="#FFFFFF", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="page",
            field=models.CharField(default="#FFFFFF", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="sidebar",
            field=models.CharField(default="#FFFFFF", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="sidebar_active",
            field=models.CharField(default="#1976D2", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="sidebar_active_text",
            field=models.CharField(default="#FFFFFF", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="sidebar_hover",
            field=models.CharField(default="#F5F5F5", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="sidebar_text",
            field=models.CharField(default="#333333", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="text_dark",
            field=models.CharField(default="#1D1D1D", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="text_light",
            field=models.CharField(default="#FFFFFF", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="text_link",
            field=models.CharField(default="#1976D2", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="text_muted",
            field=models.CharField(default="#9E9E9E", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="text_primary",
            field=models.CharField(default="#000000", max_length=50),
        ),
        migrations.AddField(
            model_name="theme",
            name="text_secondary",
            field=models.CharField(default="#666666", max_length=50),
        ),
        migrations.AlterField(
            model_name="theme",
            name="accent",
            field=models.CharField(default="#9C27B0", max_length=50),
        ),
        migrations.AlterField(
            model_name="theme",
            name="dark",
            field=models.CharField(default="#1D1D1D", max_length=50),
        ),
        migrations.AlterField(
            model_name="theme",
            name="primary",
            field=models.CharField(default="#1976D2", max_length=50),
        ),
        migrations.AlterField(
            model_name="theme",
            name="warning",
            field=models.CharField(default="#F2C037", max_length=50),
        ),
        migrations.CreateModel(
            name="AnimationSetting",
            fields=[
                (
                    "id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                ("deleted_at", models.DateTimeField(blank=True, null=True)),
                (
                    "estado",
                    models.IntegerField(
                        choices=[(0, "Inativo"), (1, "Ativo")], default=0, null=True
                    ),
                ),
                ("nome", models.CharField(max_length=100)),
                ("enable_animations", models.BooleanField(default=True)),
                (
                    "animation_speed",
                    models.CharField(
                        choices=[
                            ("slow", "Slow"),
                            ("normal", "Normal"),
                            ("fast", "Fast"),
                        ],
                        default="normal",
                        max_length=20,
                    ),
                ),
                (
                    "page_transition",
                    models.CharField(
                        choices=[
                            ("none", "None"),
                            ("fade", "Fade"),
                            ("slide-left", "Slide Left"),
                            ("slide-right", "Slide Right"),
                            ("slide-up", "Slide Up"),
                            ("slide-down", "Slide Down"),
                            ("scale", "Scale"),
                            ("zoom", "Zoom"),
                        ],
                        default="fade",
                        max_length=50,
                    ),
                ),
                (
                    "button_animation",
                    models.CharField(
                        choices=[
                            ("none", "None"),
                            ("ripple", "Ripple"),
                            ("pulse", "Pulse"),
                            ("bounce", "Bounce"),
                            ("scale", "Scale"),
                        ],
                        default="ripple",
                        max_length=50,
                    ),
                ),
                ("hover_effect", models.BooleanField(default=True)),
                (
                    "hover_style",
                    models.CharField(
                        choices=[
                            ("none", "None"),
                            ("lift", "Lift"),
                            ("shadow", "Shadow"),
                            ("grow", "Grow"),
                            ("glow", "Glow"),
                        ],
                        default="lift",
                        max_length=50,
                    ),
                ),
                (
                    "card_animation",
                    models.CharField(
                        choices=[
                            ("none", "None"),
                            ("fade", "Fade"),
                            ("slide-up", "Slide Up"),
                            ("zoom", "Zoom"),
                        ],
                        default="fade",
                        max_length=50,
                    ),
                ),
                (
                    "modal_animation",
                    models.CharField(
                        choices=[
                            ("none", "None"),
                            ("scale", "Scale"),
                            ("fade", "Fade"),
                            ("slide-up", "Slide Up"),
                        ],
                        default="scale",
                        max_length=50,
                    ),
                ),
                (
                    "created_by",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="%(class)s_created",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "updated_by",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="%(class)s_updated",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "verbose_name": "Animation Setting",
                "verbose_name_plural": "Animation Settings",
            },
        ),
        migrations.AddField(
            model_name="entidade",
            name="animation_settings",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="django_resaas.animationsetting",
            ),
        ),
        migrations.AddField(
            model_name="tipoentidade",
            name="animation_settings",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="django_resaas.animationsetting",
            ),
        ),
        migrations.CreateModel(
            name="Typography",
            fields=[
                (
                    "id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                ("deleted_at", models.DateTimeField(blank=True, null=True)),
                (
                    "estado",
                    models.IntegerField(
                        choices=[(0, "Inativo"), (1, "Ativo")], default=0, null=True
                    ),
                ),
                ("nome", models.CharField(max_length=100)),
                (
                    "font_family",
                    models.CharField(
                        choices=[
                            ("Roboto", "Roboto"),
                            ("Inter", "Inter"),
                            ("Open Sans", "Open Sans"),
                            ("Lato", "Lato"),
                            ("Poppins", "Poppins"),
                            ("Montserrat", "Montserrat"),
                            ("Source Sans Pro", "Source Sans Pro"),
                            ("Nunito", "Nunito"),
                            ("Raleway", "Raleway"),
                            ("Ubuntu", "Ubuntu"),
                            ("Playfair Display", "Playfair Display"),
                            ("Merriweather", "Merriweather"),
                        ],
                        default="Roboto",
                        max_length=100,
                    ),
                ),
                (
                    "font_family_monospace",
                    models.CharField(
                        choices=[
                            ("monospace", "Default Monospace"),
                            ("Fira Code", "Fira Code"),
                            ("JetBrains Mono", "JetBrains Mono"),
                            ("Source Code Pro", "Source Code Pro"),
                            ("Roboto Mono", "Roboto Mono"),
                        ],
                        default="monospace",
                        max_length=100,
                    ),
                ),
                ("font_size_base", models.IntegerField(default=14)),
                ("font_size_h1", models.IntegerField(default=32)),
                ("font_size_h2", models.IntegerField(default=28)),
                ("font_size_h3", models.IntegerField(default=24)),
                ("font_size_h4", models.IntegerField(default=20)),
                ("font_size_h5", models.IntegerField(default=18)),
                ("font_size_h6", models.IntegerField(default=16)),
                ("font_size_body", models.IntegerField(default=14)),
                ("font_size_caption", models.IntegerField(default=12)),
                ("font_size_small", models.IntegerField(default=11)),
                ("font_weight_light", models.IntegerField(default=300)),
                ("font_weight_normal", models.IntegerField(default=400)),
                ("font_weight_medium", models.IntegerField(default=500)),
                ("font_weight_bold", models.IntegerField(default=700)),
                ("line_height", models.FloatField(default=1.5)),
                ("letter_spacing", models.FloatField(default=0)),
                ("uppercase_headings", models.BooleanField(default=False)),
                (
                    "created_by",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="%(class)s_created",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "updated_by",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="%(class)s_updated",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "verbose_name": "Typography",
                "verbose_name_plural": "Typography",
            },
        ),
        migrations.AddField(
            model_name="entidade",
            name="typography",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="django_resaas.typography",
            ),
        ),
        migrations.AddField(
            model_name="tipoentidade",
            name="typography",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="django_resaas.typography",
            ),
        ),
    ]
